@@ -16,6 +16,8 @@
 
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
 QGeoTiledMappingManagerEngineOsm::QGeoTiledMappingManagerEngineOsm(const QVariantMap &parameters, QGeoServiceProvider::Error *error, QString *errorString)
 :   QGeoTiledMappingManagerEngine()
 {
@@ -77,21 +79,23 @@ QGeoTiledMappingManagerEngineOsm::QGeoTiledMappingManagerEngineOsm(const QVarian
     QList<TileProvider *> providers_terrain;
     QList<TileProvider *> providers_hiking;
     if (highdpi) {
-        providers_street.push_back(new TileProvider(domain + "street-hires", true));
-        providers_satellite.push_back(new TileProvider(domain + "satellite-hires", true));
-        providers_cycle.push_back(new TileProvider(domain + "cycle-hires", true));
-        providers_transit.push_back(new TileProvider(domain + "transit-hires", true));
-        providers_nighttransit.push_back(new TileProvider(domain + "night-transit-hires", true));
-        providers_terrain.push_back(new TileProvider(domain + "terrain-hires", true));
-        providers_hiking.push_back(new TileProvider(domain + "hiking-hires", true));
+        providers_street.push_back(new TileProvider(QString(domain + "street-hires"_L1), true));
+        providers_satellite.push_back(
+                new TileProvider(QString(domain + "satellite-hires"_L1), true));
+        providers_cycle.push_back(new TileProvider(QString(domain + "cycle-hires"_L1), true));
+        providers_transit.push_back(new TileProvider(QString(domain + "transit-hires"_L1), true));
+        providers_nighttransit.push_back(
+                new TileProvider(QString(domain + "night-transit-hires"_L1), true));
+        providers_terrain.push_back(new TileProvider(QString(domain + "terrain-hires"_L1), true));
+        providers_hiking.push_back(new TileProvider(QString(domain + "hiking-hires"_L1), true));
     }
-    providers_street.push_back(new TileProvider(domain + "street"));
-    providers_satellite.push_back(new TileProvider(domain + "satellite"));
-    providers_cycle.push_back(new TileProvider(domain + "cycle"));
-    providers_transit.push_back(new TileProvider(domain + "transit"));
-    providers_nighttransit.push_back(new TileProvider(domain + "night-transit"));
-    providers_terrain.push_back(new TileProvider(domain + "terrain"));
-    providers_hiking.push_back(new TileProvider(domain + "hiking"));
+    providers_street.push_back(new TileProvider(QString(domain + "street"_L1)));
+    providers_satellite.push_back(new TileProvider(QString(domain + "satellite"_L1)));
+    providers_cycle.push_back(new TileProvider(QString(domain + "cycle"_L1)));
+    providers_transit.push_back(new TileProvider(QString(domain + "transit"_L1)));
+    providers_nighttransit.push_back(new TileProvider(QString(domain + "night-transit"_L1)));
+    providers_terrain.push_back(new TileProvider(QString(domain + "terrain"_L1)));
+    providers_hiking.push_back(new TileProvider(QString(domain + "hiking"_L1)));
     // Backups
     const QDateTime defaultTs = QDateTime::fromString(QStringLiteral("2016-06-01T00:00:00"), Qt::ISODate);
     providers_street.push_back(
